# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.7
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class PagePublish(BaseModel):
    """
    PagePublish
    """
    portal_urls: conlist(StrictStr) = Field(...)
    id: StrictInt = Field(...)
    title: StrictStr = Field(...)
    favicon_url: Optional[StrictStr] = None
    path: StrictStr = Field(...)
    html: StrictStr = Field(...)
    css: StrictStr = Field(...)
    js: StrictStr = Field(...)
    editor_version: StrictInt = Field(...)
    noindex: Optional[StrictBool] = None
    __properties = ["portal_urls", "id", "title", "favicon_url", "path", "html", "css", "js", "editor_version", "noindex"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PagePublish:
        """Create an instance of PagePublish from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PagePublish:
        """Create an instance of PagePublish from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PagePublish.parse_obj(obj)

        _obj = PagePublish.parse_obj({
            "portal_urls": obj.get("portal_urls"),
            "id": obj.get("id"),
            "title": obj.get("title"),
            "favicon_url": obj.get("favicon_url"),
            "path": obj.get("path"),
            "html": obj.get("html"),
            "css": obj.get("css"),
            "js": obj.get("js"),
            "editor_version": obj.get("editor_version"),
            "noindex": obj.get("noindex")
        })
        return _obj


