# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.7
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from static_server_connector.models.page_publish import PagePublish  # noqa: E501

class TestPagePublish(unittest.TestCase):
    """PagePublish unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PagePublish:
        """Test PagePublish
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PagePublish`
        """
        model = PagePublish()  # noqa: E501
        if include_optional:
            return PagePublish(
                portal_urls = [
                    ''
                    ],
                id = 56,
                title = '',
                favicon_url = '',
                path = '',
                html = '',
                css = '',
                js = '',
                editor_version = 56,
                noindex = True
            )
        else:
            return PagePublish(
                portal_urls = [
                    ''
                    ],
                id = 56,
                title = '',
                path = '',
                html = '',
                css = '',
                js = '',
                editor_version = 56,
        )
        """

    def testPagePublish(self):
        """Test PagePublish"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
